-- Tests for latte.cpkg
Package $apcocoa/ts/latte


Define Initialize()
EndDefine;



--Count without rational coefficients
Define TestLatte01()

TestRing::=QQ[x,y];

Using TestRing Do
  Equations := [];
  LesserEq := [x-1, x+y-1];
  GreaterEq := [x,y];
  Result:=Latte.Count(Equations, LesserEq, GreaterEq);
  Expected:=3;
  $apcocoa/ts/assert.AssertEqualsExact(Result, Expected, "TODO: Some error message!");

EndUsing;

EndDefine;



--Count with rational coefficients
Define TestLatte02()

TestRing::=QQ[x,y];

Using TestRing Do
  Equations := [];
  LesserEq := [1/2*x-1, x+1/3y-1];
  GreaterEq := [x,y];
  Result:=Latte.Count(Equations, LesserEq, GreaterEq);
  Expected:=5;
  $apcocoa/ts/assert.AssertEqualsExact(Result, Expected, "TODO: Some error message!");

EndUsing;

EndDefine;



--Count with unbound polyhedron
Define TestLatte03()

TestRing::=QQ[x,y];

Using TestRing Do
  Equations := [];
  LesserEq := [x-1, x-y-1];
  GreaterEq := [x,y];
  Result:=Latte.Count(Equations, LesserEq, GreaterEq);
  Expected:=0;
  $apcocoa/ts/assert.AssertEqualsExact(Result, Expected, "TODO: Some error message!");
EndUsing;

EndDefine;



--Count with empty polyhedral
Define TestLatte04()

TestRing::=QQ[x,y];

Using TestRing Do
  Equations := [];
  LesserEq := [-x+11, x+y-1];
  GreaterEq := [x,y];
  Result:=Latte.Count(Equations, LesserEq, GreaterEq);
  Expected:=0;
  $apcocoa/ts/assert.AssertEqualsExact(Result, Expected, "TODO: Some error message!");
EndUsing;

EndDefine;



--Ehrhart
Define TestLatte05()

TestRing::=QQ[x,y];

Using TestRing Do
  Equations := [];
  LesserEq := [x-1, x+y-1];
  GreaterEq := [x,y];
  Result:=Latte.Ehrhart(Equations, LesserEq, GreaterEq);
  Expected:=-1/(x^3 - 3x^2 + 3x - 1);
  $apcocoa/ts/assert.AssertEqualsExact(Result, Expected, "TODO: Some error message!");
EndUsing;

EndDefine;



--Maximize
Define TestLatte06()

TestRing::=QQ[x,y];

Using TestRing Do
  Equations := [];
  LesserEq := [x-1, x+y-1];
  GreaterEq := [x,y];
  ObjectiveF := x + 2y;
  Result:=Latte.Maximize(Equations, LesserEq, GreaterEq, ObjectiveF);
  Expected:=[[0, 1], 2, [1, 2]];
  $apcocoa/ts/assert.AssertEqualsExact(Result, Expected, "TODO: Some error message!");
EndUsing;

EndDefine;


EndPackage;